@@ -65,20 +65,18 @@
 #include "videowidgetplugin.h"
 #include "volumesliderplugin.h"
 
-#include <QtDesigner/QDesignerCustomWidgetCollectionInterface>
-#include <QtCore/qplugin.h>
+#include <QDesignerCustomWidgetCollectionInterface>
+#include <qplugin.h>
 
 class PhononCollection: public QObject, public QDesignerCustomWidgetCollectionInterface
 {
     Q_OBJECT
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     Q_PLUGIN_METADATA(IID "org.kde.phonon.PhononCollection")
-#endif
     Q_INTERFACES(QDesignerCustomWidgetCollectionInterface)
 public:
-    explicit PhononCollection(QObject *parent = 0);
+    explicit PhononCollection(QObject *parent = nullptr);
 
-    virtual QList<QDesignerCustomWidgetInterface*> customWidgets() const;
+    virtual QList<QDesignerCustomWidgetInterface*> customWidgets() const override;
 
 private:
     QList<QDesignerCustomWidgetInterface*> m_plugins;
@@ -99,8 +97,4 @@ QList<QDesignerCustomWidgetInterface*> PhononCollection::customWidgets() const
     return m_plugins;
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-Q_EXPORT_PLUGIN(PhononCollection)
-#endif
-
 #include "phononcollection.moc"
