@@ -42,7 +42,7 @@
 #ifndef SEEKSLIDER_PLUGIN_H
 #define SEEKSLIDER_PLUGIN_H
 
-#include <QtDesigner/QDesignerCustomWidgetInterface>
+#include <QDesignerCustomWidgetInterface>
 
 class SeekSliderPlugin: public QObject, public QDesignerCustomWidgetInterface
 {
@@ -51,17 +51,17 @@ class SeekSliderPlugin: public QObject, public QDesignerCustomWidgetInterface
 public:
     explicit SeekSliderPlugin(const QString &group, QObject *parent = 0);
 
-    virtual QString name() const;
-    virtual QString group() const;
-    virtual QString toolTip() const;
-    virtual QString whatsThis() const;
-    virtual QString includeFile() const;
-    virtual QIcon icon() const;
-    virtual bool isContainer() const;
-    virtual QWidget *createWidget(QWidget *parent);
-    virtual bool isInitialized() const;
-    virtual void initialize(QDesignerFormEditorInterface *core);
-    virtual QString domXml() const;
+    virtual QString name() const override;
+    virtual QString group() const override;
+    virtual QString toolTip() const override;
+    virtual QString whatsThis() const override;
+    virtual QString includeFile() const override;
+    virtual QIcon icon() const override;
+    virtual bool isContainer() const override;
+    virtual QWidget *createWidget(QWidget *parent) override;
+    virtual bool isInitialized() const override;
+    virtual void initialize(QDesignerFormEditorInterface *core) override;
+    virtual QString domXml() const override;
 
 private:
     const QString m_group;
