@@ -38,9 +38,6 @@
 #include <QtCore/QPluginLoader>
 #include <QtCore/QPointer>
 #include <QtCore/QSettings>
-#ifndef PHONON_NO_DBUS
-#include <QtDBus/QtDBus>
-#endif
 #include <QApplication>
 #include <QMessageBox>
 #include <QString>
@@ -57,8 +54,6 @@ class FactoryPrivate : public Phonon::Factory::Sender
         FactoryPrivate();
         ~FactoryPrivate();
         bool tryCreateBackend(const QString &path);
-        // Implementation depends on Qt version.
-        bool createSuitableBackend(const QString &libPath, const QList<QString> &plugins);
         bool createBackend();
 #ifndef QT_NO_PHONON_PLATFORMPLUGIN
         PlatformPlugin *platformPlugin();
@@ -72,13 +67,6 @@ class FactoryPrivate : public Phonon::Factory::Sender
         QList<MediaNodePrivate *> mediaNodePrivateList;
 
     private Q_SLOTS:
-        /**
-         * This is called via DBUS when the user changes the Phonon Backend.
-         */
-#ifndef PHONON_NO_DBUS
-        void phononBackendChanged();
-#endif //PHONON_NO_DBUS
-
         /**
          * unregisters the backend object
          */
@@ -91,13 +79,13 @@ PHONON_GLOBAL_STATIC(Phonon::FactoryPrivate, globalFactory)
 
 static inline void ensureLibraryPathSet()
 {
-#ifdef PHONON_LIBRARY_PATH
+#ifdef PHONON_PLUGIN_PATH
     static bool done = false;
     if (!done) {
         done = true;
-        QCoreApplication::addLibraryPath(QLatin1String(PHONON_LIBRARY_PATH));
+        QCoreApplication::addLibraryPath(QLatin1String(PHONON_PLUGIN_PATH));
     }
-#endif // PHONON_LIBRARY_PATH
+#endif // PHONON_PLUGIN_PATH
 }
 
 void Factory::setBackend(QObject *b)
@@ -126,120 +114,12 @@ bool FactoryPrivate::tryCreateBackend(const QString &path)
     return false;
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-struct BackendDescriptor {
-    explicit BackendDescriptor(const QString &path)
-        : isValid(false)
-    {
-        QPluginLoader loader(path);
-
-        iid = loader.metaData().value(QLatin1String("IID")).toString();
-
-        const QJsonObject metaData = loader.metaData().value(QLatin1String("MetaData")).toObject();
-        name = metaData.value(QLatin1String("Name")).toString();
-        icon = metaData.value(QLatin1String("Icon")).toString();
-        version = metaData.value(QLatin1String("Version")).toString();
-        website = metaData.value(QLatin1String("Website")).toString();
-        preference = metaData.value(QLatin1String("InitialPreference")).toDouble();
-
-        pluginPath = path;
-
-        if (name.isEmpty())
-            name = QFileInfo(path).baseName();
-
-        if (iid.isEmpty())
-            return; // Not valid.
-
-        isValid = true;
-    }
-
-    bool isValid;
-
-    QString iid;
-
-    QString name;
-    QString icon;
-    QString version;
-    QString website;
-    int preference;
-
-    QString pluginPath;
-
-    /** Implemented for qSort(QList) */
-    bool operator <(const BackendDescriptor &rhs) const
-    {
-        return this->preference < rhs.preference;
-    }
-};
-
-bool FactoryPrivate::createSuitableBackend(const QString &libPath, const QList<QString> &plugins)
-{
-    // User configured preference.
-    QList<QString> iidPreference;
-    QSettings settings("kde.org", "libphonon");
-    const int size = settings.beginReadArray("Backends");
-    for (int i = 0; i < size; ++i) {
-        settings.setArrayIndex(i);
-        iidPreference.append(settings.value("iid").toString());
-    }
-    settings.endArray();
-
-    // Find physical backend plugins.
-    QList<BackendDescriptor> foundBackends;
-    foreach (const QString &plugin, plugins) {
-        BackendDescriptor descriptor(libPath + plugin);
-        if (!descriptor.isValid)
-            continue;
-        foundBackends.append(descriptor);
-    }
-    qSort(foundBackends);
-
-    // Try to pick a preferred backend.
-    foreach (const QString &iid, iidPreference) {
-        // This is slightly inefficient but we only have 2 backends :P
-        // Also using a list requires less overall code than QMap<iid,desc>.
-        QList<BackendDescriptor>::iterator it;
-        for (it = foundBackends.begin(); it != foundBackends.end(); ++it) {
-            const BackendDescriptor &descriptor = *it;
-            if (descriptor.iid != iid) {
-                continue;
-            }
-            if (tryCreateBackend(descriptor.pluginPath)) {
-                return true;
-            } else { // Drop backends that failed to construct.
-                it = foundBackends.erase(it);
-                if (it == foundBackends.end())
-                    break;
-            }
-        }
-    }
-
-    // No Preferred backend could be constructed. Try all remaining backends
-    // in order of initial preference.
-    // Note that unconstructable backends have been dropped previously.
-    foreach (const BackendDescriptor &descriptor, foundBackends) {
-        if (tryCreateBackend(descriptor.pluginPath))
-            return true;
-    }
-    return false;
-}
-#else // Qt 4
-bool FactoryPrivate::createSuitableBackend(const QString &libPath, const QList<QString> &plugins)
-{
-    foreach (const QString &plugin, plugins) {
-        if (tryCreateBackend(libPath + plugin))
-            return true;
-    }
-    return false;
-}
-#endif
-
 // This entire function is so terrible to read I hope it implodes some day.
 bool FactoryPrivate::createBackend()
 {
     pDebug() << Q_FUNC_INFO << "Phonon" << PHONON_VERSION_STR << "trying to create backend...";
 #ifndef QT_NO_LIBRARY
-    Q_ASSERT(m_backendObject == 0);
+    Q_ASSERT(m_backendObject == nullptr);
 
     // If the user defines a backend with PHONON_BACKEND this overrides the
     // platform plugin (because we cannot influence its lookup priority) and
@@ -254,60 +134,16 @@ bool FactoryPrivate::createBackend()
         m_backendObject = f->createBackend();
     }
 #endif //QT_NO_PHONON_PLATFORMPLUGIN
+
     if (!m_backendObject) {
-        ensureLibraryPathSet();
+        const auto backends = Factory::findBackends();
 
-        // could not load a backend through the platform plugin. Falling back to the default
-        // (finding the first loadable backend).
-        const QStringList paths = QCoreApplication::libraryPaths();
-        for (int i = 0; i < paths.count(); ++i) {
-#ifdef __GNUC__
-#warning this actually breaks with qmake....
-#endif
-#ifndef PHONON_BACKEND_DIR_SUFFIX
-#ifdef __GNUC__
-#error PHONON_BACKEND_DIR_SUFFIX must be defined.
-#endif
-#endif
-            const QString libPath = paths.at(i) + PHONON_BACKEND_DIR_SUFFIX;
-            const QDir dir(libPath);
-            if (!dir.exists()) {
-                pDebug() << Q_FUNC_INFO << dir.absolutePath() << "does not exist";
-                continue;
-            }
-
-            QStringList plugins(dir.entryList(QDir::Files));
-
-#ifdef Q_OS_SYMBIAN
-            /* On Symbian OS we might have two plugins, one which uses Symbian
-             * MMF framework("mmf"), and one which uses Real Networks's
-             * Helix("hxphonon"). We prefer the latter because it's more
-             * sophisticated, so we make sure the Helix backend is attempted
-             * to be loaded first, and the MMF backend is used for backup. */
-            {
-                const int helix = plugins.indexof(QLatin1String("hxphonon"));
-                if (helix != -1)
-                    plugins.move(helix, 0);
-            }
-#endif
-
-            if (!backendEnv.isEmpty()) {
-                pDebug() << "trying to load:" << backendEnv << "as first choice";
-                const int backendIndex = plugins.indexOf(QRegExp(backendEnv + ".*"));
-                if (backendIndex != -1)
-                    plugins.move(backendIndex, 0);
-            }
-
-            // This function implements a very simple trial-and-error loader for
-            // Qt 4 and on top of that a preference system for Qt 5. Therefore
-            // in Qt 5 we have backend preference independent of a platform
-            // plugin.
-            createSuitableBackend(libPath, plugins);
-
-            if (m_backendObject) {
+        for (const auto &backend : backends) {
+            if (tryCreateBackend(backend.pluginPath)) {
                 break;
             }
         }
+
         if (!m_backendObject) {
             pWarning() << Q_FUNC_INFO << "phonon backend plugin could not be loaded";
             return false;
@@ -335,19 +171,15 @@ bool FactoryPrivate::createBackend()
 FactoryPrivate::FactoryPrivate()
     :
 #ifndef QT_NO_PHONON_PLATFORMPLUGIN
-    m_platformPlugin(0),
+    m_platformPlugin(nullptr),
     m_noPlatformPlugin(false),
 #endif //QT_NO_PHONON_PLATFORMPLUGIN
-    m_backendObject(0)
+    m_backendObject(nullptr)
 {
     // Add the post routine to make sure that all other global statics (especially the ones from Qt)
     // are still available. If the FactoryPrivate dtor is called too late many bad things can happen
     // as the whole backend might still be alive.
     qAddPostRoutine(globalFactory.destroy);
-#ifndef PHONON_NO_DBUS
-    QDBusConnection::sessionBus().connect(QString(), QString(), QLatin1String("org.kde.Phonon.Factory"),
-        QLatin1String("phononBackendChanged"), this, SLOT(phononBackendChanged()));
-#endif
 }
 
 FactoryPrivate::~FactoryPrivate()
@@ -420,18 +252,6 @@ void Factory::deregisterFrontendObject(MediaNodePrivate *bp)
     }
 }
 
-#ifndef PHONON_NO_DBUS
-void FactoryPrivate::phononBackendChanged()
-{
-    QMessageBox::information(qApp->activeWindow(),
-                             tr("Restart Application"),
-                             tr("You changed the backend of the Phonon multimedia system.\n\n"
-                                "To apply this change you will need to"
-                                " restart '%1'.").arg(qAppName()));
-    emit backendChanged();
-}
-#endif //PHONON_NO_DBUS
-
 //X void Factory::freeSoundcardDevices()
 //X {
 //X     if (globalFactory->backend) {
@@ -472,6 +292,7 @@ FACTORY_IMPL(VolumeFaderEffect)
 FACTORY_IMPL(AudioOutput)
 #ifndef QT_NO_PHONON_VIDEO
 FACTORY_IMPL(VideoWidget)
+// TODO P6: remove left overs from VGO. was removed except for factory references.
 FACTORY_IMPL(VideoGraphicsObject)
 #endif //QT_NO_PHONON_VIDEO
 FACTORY_IMPL(AudioDataOutput)
@@ -487,11 +308,6 @@ PlatformPlugin *FactoryPrivate::platformPlugin()
     if (m_noPlatformPlugin) {
         return 0;
     }
-#ifndef PHONON_NO_DBUS
-    if (!QCoreApplication::instance() || QCoreApplication::applicationName().isEmpty()) {
-        pWarning() << "Phonon needs QCoreApplication::applicationName to be set to export audio output names through the DBUS interface";
-    }
-#endif
     Q_ASSERT(QCoreApplication::instance());
     const QByteArray platform_plugin_env = qgetenv("PHONON_PLATFORMPLUGIN");
     if (!platform_plugin_env.isEmpty()) {
@@ -612,6 +428,68 @@ QObject *Factory::registerQObject(QObject *o)
     return o;
 }
 
+QList<BackendDescriptor> Factory::findBackends()
+{
+    static QList<Phonon::BackendDescriptor> backendList;
+    if (!backendList.isEmpty()) {
+        return backendList;
+    }
+    ensureLibraryPathSet();
+
+    QList<QString> iidPreference;
+    QSettings settings("kde.org", "libphonon");
+    const int size = settings.beginReadArray("Backends");
+    for (int i = 0; i < size; ++i) {
+        settings.setArrayIndex(i);
+        iidPreference.append(settings.value("iid").toString());
+    }
+    settings.endArray();
+
+    // Load default preference list.
+    const QStringList paths = QCoreApplication::libraryPaths();
+    for (const QString &path : paths) {
+        const QString libPath = path + PHONON_BACKEND_DIR_SUFFIX;
+        const QDir dir(libPath);
+        if (!dir.exists()) {
+            pDebug() << Q_FUNC_INFO << dir.absolutePath() << "does not exist";
+            continue;
+        }
+
+        const QStringList plugins(dir.entryList(QDir::Files));
+        for (const QString &plugin : plugins) {
+            Phonon::BackendDescriptor bd(libPath + plugin);
+            if (!bd.isValid) {
+                continue;
+            }
+
+            const auto index = iidPreference.indexOf(bd.iid);
+            if (index >= 0) {
+                // Apply a weight. Weight strongly influences sort order.
+                bd.weight = iidPreference.size() - index;
+            }
+            backendList.append(bd);
+        }
+
+        std::sort(backendList.rbegin(), backendList.rend());
+    }
+
+    // Apply PHONON_BACKEND override if set.
+    const QString backendEnv = qEnvironmentVariable("PHONON_BACKEND");
+    if (backendEnv.isEmpty()) {
+        return backendList;
+    }
+
+    for (int i = 0; i < backendList.size(); ++i) {
+        const auto &backend = backendList.at(i);
+        if (backendEnv == backend.pluginName) {
+            backendList.move(i, 0);
+            break;
+        }
+    }
+
+    return backendList;
+}
+
 } //namespace Phonon
 
 #include "factory.moc"
